Take

Struct Take 

1.6.0 ยท Source
pub struct Take<I> { /* private fields */ }
An iterator that only iterates over the first n iterations of iter.

This struct is created by the take method on Iterator. See its documentation for more.